\name{plotRegionDiv}
\alias{plotRegionDiv}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Plot EDI results
}
\description{
This function visualises EDI analysis result by plotting the diversity score across the spatial dimensions of a tumor, much like a heatmap. There is also an option to include statistics used for generating the EDI score. }
\usage{
plotRegionDiv(imgDir, outputDir, ff, compositionDir, plotStats = FALSE, plotGridded = FALSE, q = 0.8, h = 40)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{imgDir}{
input directory; usually is a folder generated by the getCellPos function; it should contain a "CellPosAndMask" folder where cell position files are stored; a "OutputImage" folder where scaled down H&E images are stored.}
  \item{outputDir}{
output directory}
  \item{ff}{
file name}
  \item{compositionDir}{
 tumour region composition folder with files generated by getRegionalComposition function}
  \item{plotStats}{
if true will plot result statistics of clustering}
  \item{plotGridded}{
if true will plot a gridded heatmap and H&E in pdf}
  \item{q}{
parameter q defined as the same as in getEDI function}
  \item{h}{
scaling the image with scale factor; the larger the factor the smaller the output image}
}
\details{
%%  ~~ If necessary, more details than the description above ~~
}
\value{
pdf or png files}
\references{
%% ~put references to the literature/web site here ~
}
\author{
%%  ~~who you are~~
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}
\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (imgDir, outputDir, ff, compositionDir, plotStats = FALSE, 
    plotGridded = FALSE, q = 0.8, h = 40) 
{
    require(vegan)
    require(mclust)
    require(EBImage)
    tmp <- try(load(paste0(imgDir, "/CellPosAndMask/", ff, ".rdata")))
    if (class(tmp) != "try-error") {
        n <- nrow(Mask)/h
        m <- ncol(Mask)/h
        if (!paste0(ff, ".rdata") \%in\% dir(outputDir)) {
            mat <- matrix(-2, nrow = n, ncol = m)
            CellPos <- CellPos[CellPos[, 1] != "a", ]
            for (i in 1:n) for (j in 1:m) {
                idx <- (CellPos$x \%in\% ((i - 1) * h + 1):(i * 
                  h)) & (CellPos$y \%in\% ((j - 1) * h + 1):(j * 
                  h))
                if (sum(idx) > 16) 
                  mat[i, j] <- diversity(table(CellPos[idx, 1]), 
                    index = "shannon", MARGIN = 1, base = exp(1))
                if (sum(idx) > 0 & sum(idx) <= 16) 
                  mat[i, j] <- -1
            }
            save(mat, file = paste0(outputDir, "/", ff, ".rdata"))
        }
        load(paste0(outputDir, "/", ff, ".rdata"))
        res <- try(read.table(paste0(compositionDir, "/", ff, 
            ".txt"), as.is = T, sep = "\t", row.names = NULL))
        res <- data.frame(res, n = rep(1:25, times = nrow(res)\%/\%25))
        dvs <- diversity(res[, 3:5], index = "shannon", MARGIN = 1, 
            base = exp(1))
        dvs[rowSums(res[, 3:5]) < 16] <- -1
        res <- cbind(res, dvs)
        x <- dvs[dvs != -1]
        x1 <- x[x < quantile(x, q, na.rm = T) & x > quantile(x, 
            1 - q, na.rm = T)]
        cl <- Mclust(x1, G = 1:5)
        k <- rep(NA, length(dvs))
        k[dvs != -1][x < quantile(x, q, na.rm = T) & x > quantile(x, 
            1 - q, na.rm = T)] <- cl$classification
        k[dvs != -1 & is.na(k)] <- 0
        res$k <- k
        write.csv(res, file = paste0(outputDir, "/", ff, ".csv"))
        img <- readImage(paste0(imgDir, "/OutputImage/", ff, 
            "OrginialImage.jpg"))
        cols <- colorRampPalette(c("yellow", "orange", "red", 
            "darkred"))(max(cl$classification))
        col <- c("grey", "white", "white", cols, "white")
        br <- sort(aggregate(x1, list(cl$classification), min)[, 
            2])
        br <- c(-3, -1.5, -0.5, br, quantile(x, q, na.rm = T), 
            2)
        if (plotStats) {
            pdf(paste0(outputDir, "/", ff, "stats.pdf"), width = n/8, 
                height = m/8)
            plot(cl, "density")
            plot(cl, "classification")
            plot(hist(x, breaks = 30, plot = F), col = "grey", 
                border = "grey", freq = FALSE, xlab = "Microenvironmental diversity", 
                main = "")
            lines(density(x1), lty = 2)
            plot.normal.components.mclust(x1, cl)
            par(mar = c(3, 3, 3, 3))
            par(mfrow = c(1, 2))
            plot(rowSums(res[res$dvs != -1, 3:5]), res$dvs[res$dvs != 
                -1], main = paste("Before filtering cor=", signif(cor(rowSums(res[res$dvs != 
                -1, 3:5]), res$dvs[res$dvs != -1]), 2)), pch = 19, 
                cex = 0.5)
            plot(rowSums(res[res$dvs != -1 & res$k != 0, 3:5]), 
                res$dvs[res$dvs != -1 & res$k != 0], main = paste("After filtering cor=", 
                  signif(cor(rowSums(res[res$dvs != -1 & res$k != 
                    0, 3:5]), res$dvs[res$dvs != -1 & res$k != 
                    0]), 2)), pch = 19, cex = 0.5)
            dev.off()
        }
        if (plotGridded) {
            pdf(paste0(outputDir, "/", ff, "Gridded.pdf"), width = n/8, 
                height = m/8)
            par(mar = c(0, 0, 0, 0))
            plot(x = c(0, 1), y = c(0, 1), pch = "", xaxs = "i", 
                yaxs = "i")
            image(mat[, ncol(mat):1], breaks = br, col = col, 
                add = T)
            par(mar = c(0, 0, 0, 0))
            plot(x = c(1, n), y = c(1, m), pch = "", xaxs = "i", 
                yaxs = "i")
            rasterImage(aperm(img, c(2, 1, 3)), xleft = 1, xright = n, 
                ybottom = 1, ytop = m)
            grid(nrow(mat), ncol(mat))
            mask <- mat > br[4] & mat < br[9]
            mask <- channel(mask, "gray")
            mask <- resize(mask, nrow(img), ncol(img))
            img1 <- paintObjects(mask, img, col = "black")
            plot(x = c(0, n), y = c(0, m), pch = "", xaxs = "i", 
                yaxs = "i")
            rasterImage(aperm(img1, c(2, 1, 3)), xleft = 1, xright = n, 
                ybottom = 1, ytop = m)
            dev.off()
        }
        png(paste0(outputDir, "/", ff, ".png"), , width = n * 
            10, height = m * 20)
        par(mfrow = c(2, 1))
        par(mar = c(0, 0, 0, 0))
        plot(x = c(0, 1), y = c(0, 1), pch = "", xaxs = "i", 
            yaxs = "i")
        image(mat[, ncol(mat):1], breaks = br, col = col, add = T)
        par(mar = c(0, 0, 0, 0))
        plot(x = c(1, n), y = c(1, m), pch = "", xaxs = "i", 
            yaxs = "i")
        rasterImage(aperm(img, c(2, 1, 3)), xleft = 1, xright = n, 
            ybottom = 1, ytop = m)
        dev.off()
        colorBar(x, f = paste0(outputDir, "/", ff, "colorbar.pdf"), 
            br = br, digit = 2, anno = c("No tissue", "Few cells", 
                "Lower 20\%", paste0("K", 1:max(cl$classification)), 
                "Higher 20\%"), col = col, brief = FALSE)
    }
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
